/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************

/*===========================================================================================================
 * This file demos Brown-out detection of power monitoring system. Before using this code, the CONFIG bytes
 * should enable BOD and set as BOD reset or interrupt by users.
 *
 * A power supply is needed to change the operating voltage VDD.
 *=========================================================================================================*/
#include "N78E055A_059A_517A.h"

/************************************************************************************************************
*    Brown-out interrupt subroutine
************************************************************************************************************/
void BOD_ISR (void) interrupt 10    //interrupt address is 0x0053
{
    EA = 0;                         //during clearing BOF, all interrupt should be off
    TA = 0xaa;
    TA = 0x55;
    PMC &= ~0x08;                   //clear Brown-out flag BOF  
    EA = 1;
    P10 = ~P10;                     //P1.0 toggles each capture interrupt
}                                                                                                                             

/************************************************************************************************************
*    Main function 
************************************************************************************************************/
void main (void)
{
    P3 = 0;                         //P3 low if MCU free run, high during reset 
    
    /*After power on reset, BOF will be set for chip implement behavior. The user should clear BOF before
      enabling Brown-out interrupt. Or a fake BOD interrupt routine will be executed*/
    TA = 0xaa;
    TA = 0x55;
    PMC &= ~0x08;
    
    EIE |= 0x04;                    //enable Brown-out interrupt
    EA = 1;                         //global interrupt enable

    while(1)
        P11 = PMC & 0x01;           //show voltage status  
}

