/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************

//***********************************************************************************************************
//*************** Test OK      P2 = 0x66 ********************************************************************
//*************** Test Fail    P2 = 0x78 ********************************************************************
//***********************************************************************************************************
#include <stdio.h>
#include "N78E055A_059A_517A.h"
#include "Typedef.h"
#include "Common.h"

#define   ERASE_ALL_AP        0x22
#define   FLASH_READ_AP       0x00
#define   BYTE_PROGRAM_AP     0x21
//-----------------------------------------------------------------------------------------------------------
void ISP_Error(void)
{
    P2 = 0x78;
    while(1);
}
//-----------------------------------------------------------------------------------------------------------
void Enable_ISP_Mode(void)
{
    bit EA_tmp;   

    /* Enable ISP  */ 
    EA_tmp = EA;
    EA = 0;
    TA = 0xAA;
    TA = 0x55;
    CHPCON |= 0x01;     
    EA = EA_tmp;
}
//-----------------------------------------------------------------------------------------------------------
void Disable_ISP_Mode(void)
{   
    bit EA_tmp; 

    /* Disable ISP */ 
    EA_tmp = EA;
    EA = 0;
    TA = 0xAA;
    TA = 0x55;
    CHPCON &= 0xFE;
    EA = EA_tmp; 
}
//-----------------------------------------------------------------------------------------------------------
void Trigger_ISP(void)
{ 
    bit EA_tmp; 

    EA_tmp = EA;   
    EA = 0;   
    TA = 0xAA;
    TA = 0x55;
    ISPTRG |= 0x01;
    EA = EA_tmp;
}
//-----------------------------------------------------------------------------------------------------------
void Erase_4k_Data_Flash(void)
{   
     UINT16 u16Count;

     Enable_ISP_Mode();
     P2 = 0x01;
     ISPAL = 0;
     ISPCN = ERASE_ALL_AP;

     for(u16Count=0xf0;u16Count<0x100;u16Count++)
     {  
         ISPAH = u16Count;
         Trigger_ISP();
     } 
     
     Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void Erase_4k_Data_Flash_Verify(void)
{   
     UINT32 u32Count;

     Enable_ISP_Mode();
     P2 = 0x02;
     ISPAL = 0;
     ISPAH = 0xf0;
     ISPCN = FLASH_READ_AP;

     for(u32Count=0xf000;u32Count<0x10000;u32Count++)
     {      
         ISPFD = 0;    
         Trigger_ISP();

         if(ISPFD != 0xFF)
            ISP_Error();
        
         ISPAL++;
         if(ISPAL == 0)
            ISPAH++;
     } 
                 Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void Program_4K_Data_Flash(void)
{   
     UINT32 u32Count;

     Enable_ISP_Mode();
     P2 = 0x03;
     ISPAL = 0;
     ISPAH = 0xf0;
     ISPFD = 0xFF;
     ISPCN = BYTE_PROGRAM_AP;

     for(u32Count=0xf000;u32Count<0x10000;u32Count++)
     {      
         ISPFD++;     
         Trigger_ISP();
        
         ISPAL++;
         if(ISPAL == 0)
             ISPAH++;
     } 
         
     Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void Program_4K_Data_Flash_Verify(void)
{   
     UINT32 u32Count;
     UINT8  u8Read_Data;

     Enable_ISP_Mode();
     P2 = 0x04;
     ISPAL = 0;
     ISPAH = 0xf0;;
     u8Read_Data = 0x00;
     ISPCN = FLASH_READ_AP;

     for(u32Count=0xf000;u32Count<0x10000;u32Count++)
     {       
                 
         Trigger_ISP();
         if(ISPFD != u8Read_Data)
                        ISP_Error();

         ISPAL++;
         if(ISPAL == 0)
             ISPAH++;
         u8Read_Data++;          
     } 
     
     Disable_ISP_Mode();
}
//-----------------------------------------------------------------------------------------------------------
void main (void) 
{
     InitialUART0_Timer1(9600);           /* 9600 Baud Rate @ 11.0592MHz */

     printf ("\n*=====================================================================  ");
     printf ("\n*  Name: N78E055A_059A_517A ISP APROM Program Data_Flash Sample Code.   ");
     printf ("\n*=====================================================================\n");

     Erase_4k_Data_Flash();
     Erase_4k_Data_Flash_Verify();
     Program_4K_Data_Flash();
     Program_4K_Data_Flash_Verify();

     P2 = 0x66;
     printf ("\n   N78E055A_059A_517A ISP (AP TO FLASH) test pass!!!\n");

     while(1);
}               
//-----------------------------------------------------------------------------------------------------------
