/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************

/*===========================================================================================================
 * This file demos INT0/1/2/3 pin interrupt and waking up from Idle or Power Down mode. Use configuration
 * wizard to set up conditions. Observe P1.0~P1.3 for each INT0/1/2/3 interrupt.
 *=========================================================================================================*/

/*
//---------------- <<< Use Configuration Wizard in Context Menu >>> -----------------------
//
// <o0> INT0 Level/Edge Trigger Select
//     <0=> Low level triggered
//     <1=> Falling edge triggered
// <o1> INT1 Level/Edge Trigger Select
//     <0=> Low level triggered
//     <1=> Falling edge triggered
// <o2.0> INT2 Level/Edge Trigger Select
//     <0=> Low level triggered
//     <1=> Falling edge triggered
// <o2.4> INT3 Level/Edge Trigger Select
//     <0=> Low level triggered
//     <1=> Falling edge triggered
// <o3.0..1> Power Saving Mode Select
//     <1=> Idle mode
//     <2=> Power Down mode
//
//---------------- <<< end of configuration section >>> -----------------------------------
*/

#include "N78E055A_059A_517A.h"

#define INT0_TRIGGER        0
#define INT1_TRIGGER        0
#define INT2_3_TRIGGER      0x00
#define POWER_SAVING_MODE   0x02

/************************************************************************************************************
*    INT0 interrupt subroutine
************************************************************************************************************/
void INT0_ISR (void) interrupt 0    //interrupt address is 0x0003
{
    P10 = ~P10;                     //P1.0 toggles each INT0 interrupt
}

/************************************************************************************************************
*    INT1 interrupt subroutine
************************************************************************************************************/
void INT1_ISR (void) interrupt 2    //interrupt address is 0x0013
{
    P11 = ~P11;                     //P1.1 toggles each INT1 interrupt
}

/************************************************************************************************************
*    INT2 interrupt subroutine
************************************************************************************************************/
void INT2_ISR (void) interrupt 6    //interrupt address is 0x0033
{
    P12 = ~P12;                     //P1.2 toggles each INT2 interrupt
}

/************************************************************************************************************
*    INT3 interrupt subroutine
************************************************************************************************************/
void INT3_ISR (void) interrupt 7    //interrupt address is 0x003B
{
    P13 = ~P13;                     //P1.3 toggles each INT3 interrupt
}

/************************************************************************************************************
*    Main function 
************************************************************************************************************/
void main (void)
{
    IT0 = INT0_TRIGGER;
    IT1 = INT1_TRIGGER;
    XICON |= INT2_3_TRIGGER;
    EX0 = 1;                        //INT0 pin interrupt enable
    EX1 = 1;                        //INT1 pin interrupt enable
    EX2 = 1;                        //INT2 pin interrupt enable
    EX3 = 1;                        //INT3 pin interrupt enable
    EA = 1;                         //global interrupt enable

    while(1)
    {
        PCON |= POWER_SAVING_MODE;
        P17 = ~P17;                 //P1.7 toggles each Idle or Power Down mode exit
    }
}

