/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************
//  1: Receive 0x90,0x01,0x02,0x03 from Master
//  2: send 0xEF,0x14 to Master
//  3: If test ok,P12 and P13 can toggle
//***********************************************************************************************************
#include <stdio.h>
#include <intrins.h>
#include <string.h>
#include "N78E055A_059A_517A.h"
#include "Typedef.h"
#include "Define.h"
#include "Common.h"
#include "Delay.h"

#define set_SSOE        SPCR |= SET_BIT7
#define set_SPE         SPCR |= SET_BIT6
#define set_LSBFE       SPCR |= SET_BIT5
#define set_MSTR        SPCR |= SET_BIT4
#define set_CPOL        SPCR |= SET_BIT3
#define set_CPHA        SPCR |= SET_BIT2
#define set_SPR1        SPCR |= SET_BIT1
#define set_SPR0        SPCR |= SET_BIT0

#define set_DRSS        SPSR |= SET_BIT3
#define set_ESPI        EIE  |= SET_BIT0

#define clr_SSOE        SPCR &= CLR_BIT7
#define clr_SPE         SPCR &= CLR_BIT6
#define clr_LSBFE       SPCR &= CLR_BIT5
#define clr_MSTR        SPCR &= CLR_BIT4
#define clr_CPOL        SPCR &= CLR_BIT3
#define clr_CPHA        SPCR &= CLR_BIT2
#define clr_SPR1        SPCR &= CLR_BIT1
#define clr_SPR0        SPCR &= CLR_BIT0

#define clr_DRSS        SPSR &= CLR_BIT3
#define clr_SPIF        SPSR &= CLR_BIT7

#define SS_PIN          P14

UINT8   u8Receive_Data[10];
UINT16  u16CNT=0;
BIT     SPI_Send_Flag;

//-----------------------------------------------------------------------------------------------------------
void SPI_Interrupt_ISR(void) interrupt 8
{
    clr_SPIF; 
    
    if(!SPI_Send_Flag)
    {       
        u8Receive_Data[u16CNT] = SPDR;
        u16CNT ++;
    }

    SPI_Send_Flag = 0; 
}
//-----------------------------------------------------------------------------------------------------------
void Enter_Idle_Mode(void)
{
    PCON |= 0x01;
}
//-----------------------------------------------------------------------------------------------------------
void SPI_Error(void)
{
    P2 = 0x78;
    while(1);
}
//-----------------------------------------------------------------------------------------------------------
void SPI_Initial(void)
{
    /* Enable Port 0 to weakly pull-up */
    P0OR |= SET_BIT0;

    /* SPI clock = Fosc/8 */
    clr_SPR0;
    clr_SPR1;

    /* SPI in Slave mode */
    clr_MSTR;

    /* MSB first */
    clr_LSBFE;

    clr_CPOL;  
    set_CPHA;
    
    /* Enable SPI interrupt */
    set_ESPI;

    /* Enable SPI function */
    set_SPE;
}
//-----------------------------------------------------------------------------------------------------------
void main(void)
{      
    SPI_Initial();
    SPI_Send_Flag = 0;
    EA = 1;

    P3 = 0x33;  
    u16CNT = 0;

    clr_SPIF;                                
    SPDR = 0xFF;                             
    Enter_Idle_Mode(); 
    if(u8Receive_Data[0] != 0x90)            /* Receive Master 1st DATA */
        SPI_Error();   
  
    SPDR = 0xFF;
    Enter_Idle_Mode();                       
    if(u8Receive_Data[1] != 0x01)            /* Receive Master 2nd DATA */
        SPI_Error();

    SPDR = 0xFF;
    Enter_Idle_Mode();
    if(u8Receive_Data[2] != 0x02)            /* Receive Master 2rd DATA */
        SPI_Error();

    SPDR = 0xFF;
    Enter_Idle_Mode();
    if(u8Receive_Data[3] != 0x03)            /* Receive Master 4th DATA */
        SPI_Error();
    
    SPI_Send_Flag = 1;
    SPDR = 0xEF;                             /* send 1st data (0xEF) to Master */
    Enter_Idle_Mode();

    SPI_Send_Flag = 1;
    SPDR = 0x14;                             /* send 2nd data (0x14) to Master */
    Enter_Idle_Mode();

    while(1)                                 /* Test ok P13 flash */
    {
        P13 = 0;
        Delay1ms(300);
        P13 = 1;
        Delay1ms(300);
    }
}
//-----------------------------------------------------------------------------------------------------------
