/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013   
//***********************************************************************************************************

#include "Timer01.h"
#if DEMO == 2

/*===========================================================================================================
 * Before using this demo code, please set DEMO in "TImer01.h" to decide which *.c is used for different 
 * timer modes.
 *
 * This file set up Timer 0 and 1 in mode 2. The clock gating, timer/counter mode are both configured by 
 * configuration wizard. P1.0 and P1.1 toggles each Timer 0 and Timer 1 interrupt respectively. 
 *===========================================================================================================

/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
//
// <o0.2> Timer/Counter 0 Select
//     <0=> Timer                       <1=> Counter
// <o0.6> Timer/Counter 1 Select
//     <0=> Timer                       <1=> Counter
// <o0.0..1> Timer 0 Mode Select
//     <2=> (2) 8-bit auto-reload mode
// <o0.4..5> Timer 1 Mode Select
//     <2=> (2) 8-bit auto-reload mode
// <q0.3> Timer 0 Clock Hardware Gating
// <q0.7> Timer 1 Clock Hardware Gating
//
//-------- <<< end of configuration section >>> ------------------------------
*/

#include "N78E055A_059A_517A.h"

#define TIMER_MODE              0x22
#define TIMER0_RELOAD_VALUE     0x80
#define TIMER1_RELOAD_VALUE     0xc0

/************************************************************************************************************
*    TIMER 0 interrupt subroutine
************************************************************************************************************/
void Timer0_ISR (void) interrupt 1      //interrupt address is 0x000B
{  
    P10 = ~P10;                         //P1.0 toggle when interrupt
}

/************************************************************************************************************
*    TIMER 1 interrupt subroutine
************************************************************************************************************/
void Timer1_ISR (void) interrupt 3      //interrupt address is 0x001B
{
    P11 = ~P11;                         //P1.1 toggle when interrupt
}

/************************************************************************************************************
*    Main function 
************************************************************************************************************/
void main (void)
{
    TMOD = TIMER_MODE;                  //Timer 0 and Timer 1 mode configuration
    
    TH0 = TIMER0_RELOAD_VALUE;          //initial counter values 
    TL0 = TIMER0_RELOAD_VALUE;    
    TH1 = TIMER1_RELOAD_VALUE;
    TL1 = TIMER1_RELOAD_VALUE;    
    
    ET0 = 1;                            //enable Timer0 interrupt
    ET1 = 1;                            //enable Timer1 interrupt
    EA = 1;                             //enable interrupts
    TR0 = 1;                            //Timer0 run
    TR1 = 1;                            //Timer1 run
    while(1);
}

#endif
