/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************

#include "Timer2.h"
#if DEMO == 0

/*===========================================================================================================
 * Before using this demo code, please set DEMO in "TImer2.h" to decide which *.c is used for different 
 * timer modes.
 *
 * This file set up Timer 2 in Capture mode. The timer/counter mode is configured by configuration wizard.
 * P1.2 toggles each TF2 interrupt and P1.3 toggles each external T2EX interrupt.
 *===========================================================================================================

/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
//
// <o0.1> Timer/Counter 2 Select
//     <0=> Timer
//     <1=> Counter
//
//-------- <<< end of configuration section >>> ------------------------------
*/

#include "N78E055A_059A_517A.h"

#define TIMER_CONTROL   0x00 
#define TH2_INIT        0x00
#define TL2_INIT        0x00
#define RCAP2H_INIT     0x00
#define RCAP2L_INIT     0x00

/************************************************************************************************************
*    TIMER 2 interrupt subroutine
************************************************************************************************************/
void Timer2_ISR (void) interrupt 5  //interrupt address is 0x002B
{
    if (TF2)
    {
        TF2 = 0;
        P12 = ~P12;                 //P1.2 toggle when TF2 interrupt
    }

    if (EXF2)
    {
        EXF2 = 0;

        TR2 = 0;                    //before reloading, disable timer clock for 16-bit reloading
        TH2 = TL2 = 0;              //reload 16-bit value by software             
        TR2 = 1;

        P13 = ~P13;                 //P1.3 toggle when external T2EX interrupt
    }
}

/************************************************************************************************************
*    Main function 
************************************************************************************************************/
void main (void)
{
    T2CON |= TIMER_CONTROL;         //Timer 2 mode configuration by setting T2CON and T2MOD registers
    CP_RL2 = 1;                     //enable capture mode
    EXEN2 = 1;                      //enable capture
    
    TH2 = TH2_INIT;                 //initial counter values 
    TL2 = TL2_INIT;    
    RCAP2H = RCAP2H_INIT;
    RCAP2L = RCAP2L_INIT;    
    
    ET2 = 1;                        //enable Timer2 interrupt
    EA = 1;                         //enable interrupts
    TR2 = 1;                        //Timer2 run

    while(1)
    {
        P2 = RCAP2H;                //show captured value on P2 and P0
        P0 = RCAP2L;
    }
}

#endif