/*---------------------------------------------------------------------------------------------------------*/
/*                                                                                                         */
/* Copyright(c) 2013 Nuvoton Technology Corp. All rights reserved.                                         */
/*                                                                                                         */
/*---------------------------------------------------------------------------------------------------------*/

//***********************************************************************************************************
//  Nuvoton Technology Corp. 
//  E-Mail: MicroC-8bit@nuvoton.com
//  Date: 20/May/2013
//***********************************************************************************************************

/*===========================================================================================================
 * This file demos Watchdog Timer interrupt and reset. An oscilloscope is needed to observed P1.0 for each
 * WDT reset and ALE pin for Power-down entry and woken up indicator.
 *=========================================================================================================*/

/*
//---------------- <<< Use Configuration Wizard in Context Menu >>> -----------------------
//
// <o0.0..3> WDT counter pre-scalar
//     <0=> 1/1
//     <1=> 1/2
//     <2=> 1/8
//     <3=> 1/16
//     <4=> 1/32
//     <5=> 1/64
//     <6=> 1/128
//     <7=> 1/256
//
//---------------- <<< end of configuration section >>> -----------------------------------
*/

#include "N78E055A_059A_517A.h"
#include "Typedef.h"

#define WDT_CLK_DIV     0x00

/************************************************************************************************************
*    Main function 
************************************************************************************************************/
void main (void)
{
    bit EA_tmp;

    P10 = 0;                        //P1.0 is a WDT reset strobe, LOW when free run and HIGH during reset 

    if ((WDCON & 0x08) == 0x08)     //check WDTRF, if WDT reset occurred, P3 shows 0x55 
        P3 = 0x55; 

    /*Note that WDCON is TA protected. Before writing, TA register should be given 0xAA and 0x55*/
    EA_tmp = EA;
    EA = 0;
    TA = 0xAA;
    TA = 0x55;
    WDCON &= ~0x08;                 //clear WDTRF                        

    TA = 0xAA;
    TA = 0x55;
    WDCON |= WDT_CLK_DIV;           //select bit length of WDT counter

    TA = 0xAA;
    TA = 0x55;
    WDCON |= 0x10;                  //enable WDT running in Idle or Power-down

    TA = 0xAA;
    TA = 0x55;
    WDCON |= 0x40;                  //clear WDT counter
    EA = EA_tmp;
    while ((WDCON & 0x40) == 0x40); //waiting for WDCLR cleared by hardware 

    EA_tmp = EA;
    EA = 0;
    TA = 0xAA;
    TA = 0x55;
    WDCON |= 0x80;                  //WDT run
    EA = EA_tmp;

    while(1)
        PCON |= 0x02;               //Power-down Entry
}

